Changelog
=========

Current (2025-06-19)
--------------------


0.0.2 (2024-06-19)
------------------

* Added SAMPIC binary decoding
* Added some tools to handle hits and sensor hitmaps
* First code release on PyPI.


0.0.1 (2024-06-19)
------------------

* Test empty release
